[![Release](https://github.com/grupodyd/python-antsy/actions/workflows/release.yml/badge.svg)](https://github.com/grupodyd/python-antsy/actions/workflows/release.yml)
# python-antsy
 Python package for integration of Antsy in other applications

Installing
============

```bash
pip install python-antsy
```

Usage
=====
```python3
from python-antsy import Antsy
```

